Authors
-------

Roman Kalyakin <roman@kalyakin.com>

Based on `mongonose` plugin by Kapil Thangavelu.

Contributors
------------
 * Jay Luker (http://github.com/lbjay) <lbjay@reallywow.com>
 * Ziad Sawalha (http://github.com/ziadsawalha) 
